# Objective
## Scenarios
1. As a <user #1>, this is what I envision as my workflow:
   -
2. As a <user #2>, this is what I envision as my workflow:
   -

# Tasks for Claude Code
1. Research thoroughly and distill the value propositions and UNIQUE SELLING POINTS of our solution
   - Scrutinize and critique my scenarios, with the focus of improving the solution
2. Evaluate it using the AAA framework
   - Automate: Reduce operational costs
   - Augment: Reduce decision-making costs
   - Amplify: Reduce expertise costs (for scaling)
3. Features must sufficiently cover the following network behaviors to achieve strong network effects
   - Accessibility: Easy for users to complete a transaction
     - transaction is activity between producer and consumer, not necessarily monetary in nature)
   - Engagement: Information that are useful to users for completing a transaction
   - Personalization: Information that are curated for an intended use
   - Connection: Information sources that are connected to the platform (one or two-way)
   - Collaboration: Producers and consumers can jointly work together seamlessly
4. Document in details, your analysis in docs/01-analysis, and plans in docs/02-plans, and user flows in src/velus/docs/user-flows.
   - Use as many subdirectories and files as required
   - Name them sequentially as 01-, 02-, etc, for easy referencing

# Additional Notes
What is a Platform Model?
- Users (producers, consumers, partners)
  - Producers: Users who offer/deliver a product or service
  - Consumers: Users who consume a product or service
  - Partners: To facilitate the transaction between producers and consumers
